'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var BundlrStorageDriver = require('./BundlrStorageDriver.js');
var planUploadMetadata = require('../nftModule/planUploadMetadata.js');
var MetaplexFile = require('../../types/MetaplexFile.js');

const planUploadMetadataUsingBundlrOperationHandler = {
  handle: async (operation, metaplex, scope) => {
    const metadata = operation.input;
    const plan = await planUploadMetadata.planUploadMetadataOperationHandler.handle(operation, metaplex, scope);
    const storage = metaplex.storage();

    if (!(storage instanceof BundlrStorageDriver.BundlrStorageDriver)) {
      return plan;
    }

    const assets = planUploadMetadata.getAssetsFromJsonMetadata(metadata);
    const mockUri = 'x'.repeat(100);
    const mockUris = assets.map(() => mockUri);
    const mockedMetadata = planUploadMetadata.replaceAssetsWithUris(metadata, mockUris);
    const files = [...assets, MetaplexFile.MetaplexFile.fromJson(mockedMetadata)];
    let originalWithdrawAfterUploading = storage.shouldWithdrawAfterUploading();
    return plan.prependStep({
      name: 'Fund Bundlr wallet',
      handler: async () => {
        // In this step, we ensure the wallet has enough funds to pay for all the required
        // uploads. We also disable withdrawing after each upload and keep track of its
        // initial state. This prevents having to fund many times within this plan.
        originalWithdrawAfterUploading = storage.shouldWithdrawAfterUploading();
        storage.dontWithdrawAfterUploading();
        const needsFunding = await storage.needsFunding(files);

        if (!needsFunding) {
          return;
        }

        await storage.fund(files);
      }
    }).addStep({
      name: 'Withdraw funds from the Bundlr wallet',
      handler: async output => {
        // Since we've not withdrawn after every upload, we now need to
        // withdraw any remaining funds. After doing so, we must not
        // forget to restore the original withdrawAfterUploading.
        await storage.withdrawAll();
        originalWithdrawAfterUploading ? storage.withdrawAfterUploading() : storage.dontWithdrawAfterUploading();
        return output;
      }
    });
  }
};

exports.planUploadMetadataUsingBundlrOperationHandler = planUploadMetadataUsingBundlrOperationHandler;
//# sourceMappingURL=planUploadMetadataUsingBundlrOperationHandler.js.map
