'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var CandyMachine = require('./CandyMachine.js');
var CandyMachineProgram = require('../../programs/candyMachine/CandyMachineProgram.js');
var Operation = require('../../types/Operation.js');
var SdkError = require('../../errors/SdkError.js');
var CandyMachineAccount = require('../../programs/candyMachine/accounts/CandyMachineAccount.js');

// Operation
// -----------------

const Key = 'FindCandyMachinesByPublicKeyOperation';
const findCandyMachinesByPublicKeyFieldOperation = Operation.useOperation(Key);
// -----------------
// Handler
// -----------------
const findCandyMachinesByPublicKeyFieldOnChainOperationHandler = {
  handle: async (operation, metaplex) => {
    const {
      type,
      publicKey
    } = operation.input;
    const accounts = CandyMachineProgram.CandyMachineProgram.accounts(metaplex);
    let candyMachineQuery;

    switch (type) {
      case 'authority':
        candyMachineQuery = accounts.candyMachineAccountsForAuthority(publicKey);
        break;

      case 'wallet':
        candyMachineQuery = accounts.candyMachineAccountsForWallet(publicKey);
        break;

      default:
        throw new SdkError.UnreachableCaseError(type);
    }

    const candyMachineUnparseds = await candyMachineQuery.get();
    return candyMachineUnparseds.map(CandyMachineAccount.CandyMachineAccount.from).map(CandyMachine.CandyMachine.fromAccount);
  }
};

exports.findCandyMachinesByPublicKeyFieldOnChainOperationHandler = findCandyMachinesByPublicKeyFieldOnChainOperationHandler;
exports.findCandyMachinesByPublicKeyFieldOperation = findCandyMachinesByPublicKeyFieldOperation;
//# sourceMappingURL=findCandyMachinesByPublicKeyField.js.map
