'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var useJsonMetadataTask = require('./useJsonMetadataTask.js');
var useEditionTask = require('./useEditionTask.js');
var common = require('../../utils/common.js');
var Model = require('../../types/Model.js');

class Nft extends Model.Model {
  /** The Metadata PDA account defining the NFT. */

  /** Tasks. */

  /** Data from the Metadata account. */
  constructor(metadataAccount, metaplex) {
    super();
    this.metadataAccount = metadataAccount;
    this.metadataTask = useJsonMetadataTask.useJsonMetadataTask(metaplex, this);
    this.editionTask = useEditionTask.useEditionTask(metaplex, this);
    this.updateAuthority = metadataAccount.data.updateAuthority;
    this.mint = metadataAccount.data.mint;
    this.name = common.removeEmptyChars(metadataAccount.data.data.name);
    this.symbol = common.removeEmptyChars(metadataAccount.data.data.symbol);
    this.uri = common.removeEmptyChars(metadataAccount.data.data.uri);
    this.sellerFeeBasisPoints = metadataAccount.data.data.sellerFeeBasisPoints;
    this.creators = metadataAccount.data.data.creators;
    this.primarySaleHappened = metadataAccount.data.primarySaleHappened;
    this.isMutable = metadataAccount.data.isMutable;
    this.editionNonce = metadataAccount.data.editionNonce;
    this.tokenStandard = metadataAccount.data.tokenStandard;
    this.collection = metadataAccount.data.collection;
    this.uses = metadataAccount.data.uses;
  }

  get metadata() {
    var _this$metadataTask$ge;

    return (_this$metadataTask$ge = this.metadataTask.getResult()) !== null && _this$metadataTask$ge !== void 0 ? _this$metadataTask$ge : {};
  }

  get editionAccount() {
    var _this$editionTask$get;

    return (_this$editionTask$get = this.editionTask.getResult()) !== null && _this$editionTask$get !== void 0 ? _this$editionTask$get : null;
  }

  get originalEdition() {
    var _this$editionAccount;

    if (!((_this$editionAccount = this.editionAccount) !== null && _this$editionAccount !== void 0 && _this$editionAccount.isOriginal())) {
      return null;
    }

    return this.editionAccount.data;
  }

  get printEdition() {
    var _this$editionAccount2;

    if (!((_this$editionAccount2 = this.editionAccount) !== null && _this$editionAccount2 !== void 0 && _this$editionAccount2.isPrint())) {
      return null;
    }

    return this.editionAccount.data;
  }

  equals(other) {
    const mint = other instanceof Nft ? other.mint : other;
    return this.mint.equals(mint);
  }

  isOriginal() {
    var _this$editionAccount$, _this$editionAccount3;

    return (_this$editionAccount$ = (_this$editionAccount3 = this.editionAccount) === null || _this$editionAccount3 === void 0 ? void 0 : _this$editionAccount3.isOriginal()) !== null && _this$editionAccount$ !== void 0 ? _this$editionAccount$ : false;
  }

  isPrint() {
    var _this$editionAccount$2, _this$editionAccount4;

    return (_this$editionAccount$2 = (_this$editionAccount4 = this.editionAccount) === null || _this$editionAccount4 === void 0 ? void 0 : _this$editionAccount4.isPrint()) !== null && _this$editionAccount$2 !== void 0 ? _this$editionAccount$2 : false;
  }

}

exports.Nft = Nft;
//# sourceMappingURL=Nft.js.map
