'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var cloneDeep = require('lodash.clonedeep');
var Operation = require('../../types/Operation.js');
var Plan = require('../../utils/Plan.js');
var common = require('../../utils/common.js');
var MetaplexFile = require('../../types/MetaplexFile.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var cloneDeep__default = /*#__PURE__*/_interopDefaultLegacy(cloneDeep);

const Key = 'PlanUploadMetadataOperation';
const planUploadMetadataOperation = Operation.useOperation(Key);
const planUploadMetadataOperationHandler = {
  handle: async (operation, metaplex) => {
    const metadata = operation.input;
    const files = getAssetsFromJsonMetadata(metadata);

    if (files.length <= 0) {
      return Plan.Plan.make().addStep({
        name: 'Upload the metadata',
        handler: () => uploadMetadata(metaplex, metadata)
      });
    }

    return Plan.Plan.make().addStep({
      name: 'Upload assets',
      handler: () => uploadAssets(metaplex, metadata)
    }).addStep({
      name: 'Upload the metadata',
      handler: input => uploadMetadata(metaplex, input)
    });
  }
};

const uploadAssets = async (metaplex, input) => {
  const files = getAssetsFromJsonMetadata(input);
  const uris = await metaplex.storage().uploadAll(files);
  return replaceAssetsWithUris(input, uris);
};

const uploadMetadata = async (metaplex, metadata) => {
  const uri = await metaplex.storage().uploadJson(metadata);
  return {
    metadata,
    uri
  };
};

const getAssetsFromJsonMetadata = input => {
  const files = [];
  common.walk(input, (next, value) => {
    if (value instanceof MetaplexFile.MetaplexFile) {
      files.push(value);
    } else {
      next(value);
    }
  });
  return files;
};
const replaceAssetsWithUris = (input, replacements) => {
  const clone = cloneDeep__default["default"](input);
  let index = 0;
  common.walk(clone, (next, value, key, parent) => {
    if (value instanceof MetaplexFile.MetaplexFile && index < replacements.length) {
      parent[key] = replacements[index++];
    }

    next(value);
  });
  return clone;
};

exports.getAssetsFromJsonMetadata = getAssetsFromJsonMetadata;
exports.planUploadMetadataOperation = planUploadMetadataOperation;
exports.planUploadMetadataOperationHandler = planUploadMetadataOperationHandler;
exports.replaceAssetsWithUris = replaceAssetsWithUris;
//# sourceMappingURL=planUploadMetadata.js.map
