'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _rollupPluginBabelHelpers = require('../_virtual/_rollupPluginBabelHelpers.js');
var SdkError = require('../errors/SdkError.js');

class BaseAccount {
  constructor(accountValue) {
    _rollupPluginBabelHelpers.defineProperty(this, "exists", true);

    this.publicKey = accountValue.publicKey;
    this.executable = accountValue.executable;
    this.owner = accountValue.owner;
    this.lamports = accountValue.lamports;
    this.data = accountValue.data;
    this.rentEpoch = accountValue.rentEpoch;
  }

  static parse(unparsedAccount, accountData) {
    try {
      const data = accountData.fromAccountInfo(unparsedAccount)[0];
      return { ...unparsedAccount,
        data
      };
    } catch (error) {
      throw new SdkError.UnexpectedAccountError(unparsedAccount.publicKey, accountData.name, error);
    }
  }

  static parseMaybe(unparsedMaybeAccount, accountData) {
    if (!unparsedMaybeAccount.exists) {
      return unparsedMaybeAccount;
    }

    const parsedAccount = this.parse(unparsedMaybeAccount, accountData);
    return { ...parsedAccount,
      exists: true
    };
  }

}

exports.BaseAccount = BaseAccount;
//# sourceMappingURL=BaseAccount.js.map
