'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var Cluster = require('./types/Cluster.js');
var BundlrStorageDriver = require('./plugins/bundlrStorage/BundlrStorageDriver.js');
var CoreRpcDriver = require('./plugins/coreRpcDriver/CoreRpcDriver.js');
var CoreProgramDriver = require('./plugins/coreProgramDriver/CoreProgramDriver.js');
var CoreOperationDriver = require('./plugins/coreOperationDriver/CoreOperationDriver.js');
var plugin = require('./plugins/corePlugins/plugin.js');
var GuestIdentityDriver = require('./plugins/guestIdentity/GuestIdentityDriver.js');

class Metaplex {
  /** The connection object from Solana's SDK. */

  /** The cluster in which the connection endpoint belongs to. */

  /** Encapsulates the identity of the users interacting with the SDK. */

  /** Encapsulates where assets should be uploaded. */

  /** Encapsulates how to read and write on-chain. */

  /** Registers all recognised programs across clusters. */

  /** Registers handlers for read/write operations. */
  constructor(connection, options = {}) {
    var _options$cluster;

    this.connection = connection;
    this.cluster = (_options$cluster = options.cluster) !== null && _options$cluster !== void 0 ? _options$cluster : Cluster.resolveClusterFromConnection(connection);
    this.identityDriver = new GuestIdentityDriver.GuestIdentityDriver(this);
    this.storageDriver = new BundlrStorageDriver.BundlrStorageDriver(this);
    this.rpcDriver = new CoreRpcDriver.CoreRpcDriver(this);
    this.programDriver = new CoreProgramDriver.CoreProgramDriver(this);
    this.operationDriver = new CoreOperationDriver.CoreOperationDriver(this);
    this.use(plugin.corePlugins());
  }

  static make(connection, options = {}) {
    return new this(connection, options);
  }

  use(plugin) {
    plugin.install(this);
    return this;
  }

  identity() {
    return this.identityDriver;
  }

  setIdentityDriver(identity) {
    this.identityDriver = identity;
    return this;
  }

  storage() {
    return this.storageDriver;
  }

  setStorageDriver(storage) {
    this.storageDriver = storage;
    return this;
  }

  rpc() {
    return this.rpcDriver;
  }

  setRpcDriver(rpc) {
    this.rpcDriver = rpc;
    return this;
  }

  programs() {
    return this.programDriver;
  }

  setProgramDriver(programDriver) {
    this.programDriver = programDriver;
    return this;
  }

  operations() {
    return this.operationDriver;
  }

  setOperationDriver(operationDriver) {
    this.operationDriver = operationDriver;
    return this;
  }

}

exports.Metaplex = Metaplex;
//# sourceMappingURL=Metaplex.js.map
