'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var clientS3 = require('@aws-sdk/client-s3');
var StorageDriver = require('../../types/StorageDriver.js');
var SolAmount = require('../../utils/SolAmount.js');

class AwsStorageDriver extends StorageDriver.StorageDriver {
  constructor(metaplex, client, bucketName) {
    super(metaplex);
    this.client = client;
    this.bucketName = bucketName;
  }

  async getPrice(..._files) {
    return SolAmount.SolAmount.zero();
  }

  async upload(file) {
    const command = new clientS3.PutObjectCommand({
      Bucket: this.bucketName,
      Key: file.uniqueName,
      Body: file.toBuffer()
    });

    try {
      await this.client.send(command);
      return await this.getUrl(file.uniqueName);
    } catch (err) {
      // TODO: Custom errors.
      throw err;
    }
  }

  async getUrl(key) {
    const region = await this.client.config.region();
    const encodedKey = encodeURIComponent(key);
    return `https://s3.${region}.amazonaws.com/${this.bucketName}/${encodedKey}`;
  }

}

exports.AwsStorageDriver = AwsStorageDriver;
//# sourceMappingURL=AwsStorageDriver.js.map
