'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _rollupPluginBabelHelpers = require('../../_virtual/_rollupPluginBabelHelpers.js');
var OperationDriver = require('../../types/OperationDriver.js');
var SdkError = require('../../errors/SdkError.js');
var useTask = require('../../utils/useTask.js');

class CoreOperationDriver extends OperationDriver.OperationDriver {
  constructor(...args) {
    super(...args);

    _rollupPluginBabelHelpers.defineProperty(this, "operationHandlers", new Map());
  }

  register(operationConstructor, operationHandler) {
    this.operationHandlers.set(operationConstructor.key, operationHandler);
    return this;
  }

  get(operation) {
    const operationHandler = this.operationHandlers.get(operation.key);

    if (!operationHandler) {
      throw new SdkError.OperationHandlerMissingError(operation.key);
    }

    return operationHandler;
  }

  getTask(operation) {
    const operationHandler = this.get(operation);
    return useTask.useTask(scope => {
      return operationHandler.handle(operation, this.metaplex, scope);
    });
  }

  execute(operation, options = {}) {
    return this.getTask(operation).run(options);
  }

}

exports.CoreOperationDriver = CoreOperationDriver;
//# sourceMappingURL=CoreOperationDriver.js.map
