'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var findNftByMint = require('./findNftByMint.js');
var findNftsByMintList = require('./findNftsByMintList.js');
var findNftsByOwner = require('./findNftsByOwner.js');
var findNftsByCreator = require('./findNftsByCreator.js');
var findNftsByCandyMachine = require('./findNftsByCandyMachine.js');
var uploadMetadata = require('./uploadMetadata.js');
var planUploadMetadata = require('./planUploadMetadata.js');
var createNft = require('./createNft.js');
var updateNft = require('./updateNft.js');
var printNewEdition = require('./printNewEdition.js');
var ModuleClient = require('../../types/ModuleClient.js');

class NftClient extends ModuleClient.ModuleClient {
  findNftByMint(mint) {
    return this.metaplex.operations().execute(findNftByMint.findNftByMintOperation(mint));
  }

  findNftsByMintList(mints) {
    return this.metaplex.operations().execute(findNftsByMintList.findNftsByMintListOperation(mints));
  }

  findNftsByOwner(owner) {
    return this.metaplex.operations().execute(findNftsByOwner.findNftsByOwnerOperation(owner));
  }

  findNftsByCreator(creator, position = 1) {
    return this.metaplex.operations().execute(findNftsByCreator.findNftsByCreatorOperation({
      creator,
      position
    }));
  }

  findNftsByCandyMachine(candyMachine, version) {
    return this.metaplex.operations().execute(findNftsByCandyMachine.findNftsByCandyMachineOperation({
      candyMachine,
      version
    }));
  }

  uploadMetadata(input) {
    return this.metaplex.operations().execute(uploadMetadata.uploadMetadataOperation(input));
  }

  planUploadMetadata(input) {
    return this.metaplex.operations().execute(planUploadMetadata.planUploadMetadataOperation(input));
  }

  async createNft(input) {
    const operation = createNft.createNftOperation(input);
    const createNftOutput = await this.metaplex.operations().execute(operation);
    const nft = await this.findNftByMint(createNftOutput.mint.publicKey);
    return { ...createNftOutput,
      nft
    };
  }

  async updateNft(nft, input) {
    const operation = updateNft.updateNftOperation({ ...input,
      nft
    });
    const updateNftOutput = await this.metaplex.operations().execute(operation);
    const updatedNft = await this.findNftByMint(nft.mint);
    return { ...updateNftOutput,
      nft: updatedNft
    };
  }

  async printNewEdition(originalMint, input = {}) {
    const operation = printNewEdition.printNewEditionOperation({
      originalMint,
      ...input
    });
    const printNewEditionOutput = await this.metaplex.operations().execute(operation);
    const nft = await this.findNftByMint(printNewEditionOutput.mint.publicKey);
    return { ...printNewEditionOutput,
      nft
    };
  }

}

exports.NftClient = NftClient;
//# sourceMappingURL=NftClient.js.map
