'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var Nft = require('./Nft.js');
var GmaBuilder = require('../../utils/GmaBuilder.js');
var common = require('../../utils/common.js');
var Operation = require('../../types/Operation.js');
var MetadataAccount = require('../../programs/tokenMetadata/accounts/MetadataAccount.js');

const Key = 'FindNftsByMintListOperation';
const findNftsByMintListOperation = Operation.useOperation(Key);
const findNftsByMintListOnChainOperationHandler = {
  handle: async (operation, metaplex) => {
    const mints = operation.input;
    const metadataPdas = await Promise.all(mints.map(mint => MetadataAccount.MetadataAccount.pda(mint)));
    const metadataInfos = await GmaBuilder.GmaBuilder.make(metaplex, metadataPdas).get();
    return common.zipMap(metadataPdas, metadataInfos, (metadataPda, metadataInfo) => {
      if (!metadataInfo || !metadataInfo.exists) return null;

      try {
        const metadata = MetadataAccount.MetadataAccount.from(metadataInfo);
        return new Nft.Nft(metadata, metaplex);
      } catch (error) {
        return null;
      }
    });
  }
};

exports.findNftsByMintListOnChainOperationHandler = findNftsByMintListOnChainOperationHandler;
exports.findNftsByMintListOperation = findNftsByMintListOperation;
//# sourceMappingURL=findNftsByMintList.js.map
