'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var SdkError = require('../../errors/SdkError.js');
var IdentityDriver = require('../../types/IdentityDriver.js');

class WalletAdapterIdentityDriver extends IdentityDriver.IdentityDriver {
  constructor(metaplex, walletAdapter) {
    super(metaplex);
    this.walletAdapter = walletAdapter;
  }

  get publicKey() {
    if (!this.walletAdapter.publicKey) {
      throw new SdkError.UninitializedWalletAdapterError();
    }

    return this.walletAdapter.publicKey;
  }

  async signMessage(message) {
    if (this.walletAdapter.signMessage === undefined) {
      throw new SdkError.OperationNotSupportedByWalletAdapterError('signMessage');
    }

    return this.walletAdapter.signMessage(message);
  }

  async signTransaction(transaction) {
    if (this.walletAdapter.signTransaction === undefined) {
      throw new SdkError.OperationNotSupportedByWalletAdapterError('signTransaction');
    }

    return this.walletAdapter.signTransaction(transaction);
  }

  async signAllTransactions(transactions) {
    if (this.walletAdapter.signAllTransactions === undefined) {
      throw new SdkError.OperationNotSupportedByWalletAdapterError('signAllTransactions');
    }

    return this.walletAdapter.signAllTransactions(transactions);
  }

  async sendTransaction(transaction, _connection, options) {
    const {
      signers,
      ...sendOptions
    } = options || {}; // We accept a connection to match the wallet signature, but it is not used.
    // We use the RpcDriver to send the transaction to keep the single point of failure.

    return this.metaplex.rpc().sendTransaction(transaction, signers, sendOptions);
  }

}

exports.WalletAdapterIdentityDriver = WalletAdapterIdentityDriver;
//# sourceMappingURL=WalletAdapterIdentityDriver.js.map
