'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var buffer = require('buffer');
var mplTokenMetadata = require('@metaplex-foundation/mpl-token-metadata');
var TokenMetadataProgram = require('../TokenMetadataProgram.js');
var BaseAccount = require('../../../types/BaseAccount.js');
var Pda = require('../../../types/Pda.js');
var SdkError = require('../../../errors/SdkError.js');

class OriginalEditionAccount extends BaseAccount.BaseAccount {
  static async pda(mint) {
    return Pda.Pda.find(TokenMetadataProgram.TokenMetadataProgram.publicKey, [buffer.Buffer.from('metadata', 'utf8'), TokenMetadataProgram.TokenMetadataProgram.publicKey.toBuffer(), mint.toBuffer(), buffer.Buffer.from('edition', 'utf8')]);
  }

  static recognizes(buffer) {
    return this.recognizesV1(buffer) || this.recognizesV2(buffer);
  }

  static recognizesV1(buffer) {
    return (buffer === null || buffer === void 0 ? void 0 : buffer[0]) === mplTokenMetadata.Key.MasterEditionV1;
  }

  static recognizesV2(buffer) {
    return (buffer === null || buffer === void 0 ? void 0 : buffer[0]) === mplTokenMetadata.Key.MasterEditionV2;
  }

  static from(unparsedAccount) {
    if (!this.recognizes(unparsedAccount.data)) {
      throw new SdkError.UnexpectedAccountError(unparsedAccount.publicKey, 'MasterEditionV1|MasterEditionV2');
    }

    const accountData = this.recognizesV1(unparsedAccount.data) ? mplTokenMetadata.MasterEditionV1 : mplTokenMetadata.MasterEditionV2;
    return new OriginalEditionAccount(this.parse(unparsedAccount, accountData));
  }

  static fromMaybe(maybe) {
    return maybe.exists ? this.from(maybe) : maybe;
  }

}

exports.OriginalEditionAccount = OriginalEditionAccount;
//# sourceMappingURL=OriginalEditionAccount.js.map
