'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var buffer = require('buffer');
var common = require('../utils/common.js');
var SdkError = require('../errors/SdkError.js');

class MetaplexFile {
  constructor(content, fileName, options = {}) {
    var _options$displayName, _options$uniqueName, _options$contentType, _options$extension, _options$tags;

    this.buffer = MetaplexFile.parseContent(content);
    this.fileName = fileName;
    this.displayName = (_options$displayName = options.displayName) !== null && _options$displayName !== void 0 ? _options$displayName : fileName;
    this.uniqueName = (_options$uniqueName = options.uniqueName) !== null && _options$uniqueName !== void 0 ? _options$uniqueName : common.randomStr();
    this.contentType = (_options$contentType = options.contentType) !== null && _options$contentType !== void 0 ? _options$contentType : common.getContentType(fileName);
    this.extension = (_options$extension = options.extension) !== null && _options$extension !== void 0 ? _options$extension : common.getExtension(fileName);
    this.tags = (_options$tags = options.tags) !== null && _options$tags !== void 0 ? _options$tags : [];
  }

  static async fromFile(file, options = {}) {
    const buffer = await file.arrayBuffer();
    return new this(buffer, file.name, options);
  }

  static fromJson(json, fileName = 'inline.json', options = {}) {
    let jsonString;

    try {
      jsonString = JSON.stringify(json);
    } catch (error) {
      throw new SdkError.InvalidJsonVariableError(error);
    }

    return new this(jsonString, fileName, options);
  }

  static parseContent(content) {
    if (content instanceof ArrayBuffer) {
      return buffer.Buffer.from(new Uint8Array(content));
    }

    return buffer.Buffer.from(content);
  }

  getTagsWithContentType() {
    if (!this.contentType) {
      return this.tags;
    }

    return [{
      name: 'Content-Type',
      value: this.contentType
    }, ...this.tags];
  }

  getBytes() {
    return this.buffer.byteLength;
  }

  toBuffer() {
    return this.buffer;
  }

  toString() {
    return this.buffer.toString();
  }

  toGlobalFile() {
    return new File([this.buffer], this.fileName);
  }

}

exports.MetaplexFile = MetaplexFile;
//# sourceMappingURL=MetaplexFile.js.map
