import { defineProperty as _defineProperty } from '../../_virtual/_rollupPluginBabelHelpers.js';
import { OperationDriver } from '../../types/OperationDriver.js';
import { OperationHandlerMissingError } from '../../errors/SdkError.js';
import { useTask } from '../../utils/useTask.js';

class CoreOperationDriver extends OperationDriver {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "operationHandlers", new Map());
  }

  register(operationConstructor, operationHandler) {
    this.operationHandlers.set(operationConstructor.key, operationHandler);
    return this;
  }

  get(operation) {
    const operationHandler = this.operationHandlers.get(operation.key);

    if (!operationHandler) {
      throw new OperationHandlerMissingError(operation.key);
    }

    return operationHandler;
  }

  getTask(operation) {
    const operationHandler = this.get(operation);
    return useTask(scope => {
      return operationHandler.handle(operation, this.metaplex, scope);
    });
  }

  execute(operation, options = {}) {
    return this.getTask(operation).run(options);
  }

}

export { CoreOperationDriver };
//# sourceMappingURL=CoreOperationDriver.js.map
