import nacl from 'tweetnacl';
import { IdentityDriver } from '../../types/IdentityDriver.js';

class KeypairIdentityDriver extends IdentityDriver {
  constructor(metaplex, keypair) {
    super(metaplex);
    this.keypair = keypair;
    this.publicKey = keypair.publicKey;
    this.secretKey = keypair.secretKey;
  }

  async signMessage(message) {
    return nacl.sign.detached(message, this.secretKey);
  }

  async signTransaction(transaction) {
    // TODO: Handle Error: Transaction recentBlockhash required.
    transaction.partialSign(this.keypair);
    return transaction;
  }

  async signAllTransactions(transactions) {
    return Promise.all(transactions.map(transaction => this.signTransaction(transaction)));
  }

}

export { KeypairIdentityDriver };
//# sourceMappingURL=KeypairIdentityDriver.js.map
