import { findNftByMintOperation } from './findNftByMint.js';
import { findNftsByMintListOperation } from './findNftsByMintList.js';
import { findNftsByOwnerOperation } from './findNftsByOwner.js';
import { findNftsByCreatorOperation } from './findNftsByCreator.js';
import { findNftsByCandyMachineOperation } from './findNftsByCandyMachine.js';
import { uploadMetadataOperation } from './uploadMetadata.js';
import { planUploadMetadataOperation } from './planUploadMetadata.js';
import { createNftOperation } from './createNft.js';
import { updateNftOperation } from './updateNft.js';
import { printNewEditionOperation } from './printNewEdition.js';
import { ModuleClient } from '../../types/ModuleClient.js';

class NftClient extends ModuleClient {
  findNftByMint(mint) {
    return this.metaplex.operations().execute(findNftByMintOperation(mint));
  }

  findNftsByMintList(mints) {
    return this.metaplex.operations().execute(findNftsByMintListOperation(mints));
  }

  findNftsByOwner(owner) {
    return this.metaplex.operations().execute(findNftsByOwnerOperation(owner));
  }

  findNftsByCreator(creator, position = 1) {
    return this.metaplex.operations().execute(findNftsByCreatorOperation({
      creator,
      position
    }));
  }

  findNftsByCandyMachine(candyMachine, version) {
    return this.metaplex.operations().execute(findNftsByCandyMachineOperation({
      candyMachine,
      version
    }));
  }

  uploadMetadata(input) {
    return this.metaplex.operations().execute(uploadMetadataOperation(input));
  }

  planUploadMetadata(input) {
    return this.metaplex.operations().execute(planUploadMetadataOperation(input));
  }

  async createNft(input) {
    const operation = createNftOperation(input);
    const createNftOutput = await this.metaplex.operations().execute(operation);
    const nft = await this.findNftByMint(createNftOutput.mint.publicKey);
    return { ...createNftOutput,
      nft
    };
  }

  async updateNft(nft, input) {
    const operation = updateNftOperation({ ...input,
      nft
    });
    const updateNftOutput = await this.metaplex.operations().execute(operation);
    const updatedNft = await this.findNftByMint(nft.mint);
    return { ...updateNftOutput,
      nft: updatedNft
    };
  }

  async printNewEdition(originalMint, input = {}) {
    const operation = printNewEditionOperation({
      originalMint,
      ...input
    });
    const printNewEditionOutput = await this.metaplex.operations().execute(operation);
    const nft = await this.findNftByMint(printNewEditionOutput.mint.publicKey);
    return { ...printNewEditionOutput,
      nft
    };
  }

}

export { NftClient };
//# sourceMappingURL=NftClient.js.map
