import cloneDeep from 'lodash.clonedeep';
import { useOperation } from '../../types/Operation.js';
import { Plan } from '../../utils/Plan.js';
import { walk } from '../../utils/common.js';
import { MetaplexFile } from '../../types/MetaplexFile.js';

const Key = 'PlanUploadMetadataOperation';
const planUploadMetadataOperation = useOperation(Key);
const planUploadMetadataOperationHandler = {
  handle: async (operation, metaplex) => {
    const metadata = operation.input;
    const files = getAssetsFromJsonMetadata(metadata);

    if (files.length <= 0) {
      return Plan.make().addStep({
        name: 'Upload the metadata',
        handler: () => uploadMetadata(metaplex, metadata)
      });
    }

    return Plan.make().addStep({
      name: 'Upload assets',
      handler: () => uploadAssets(metaplex, metadata)
    }).addStep({
      name: 'Upload the metadata',
      handler: input => uploadMetadata(metaplex, input)
    });
  }
};

const uploadAssets = async (metaplex, input) => {
  const files = getAssetsFromJsonMetadata(input);
  const uris = await metaplex.storage().uploadAll(files);
  return replaceAssetsWithUris(input, uris);
};

const uploadMetadata = async (metaplex, metadata) => {
  const uri = await metaplex.storage().uploadJson(metadata);
  return {
    metadata,
    uri
  };
};

const getAssetsFromJsonMetadata = input => {
  const files = [];
  walk(input, (next, value) => {
    if (value instanceof MetaplexFile) {
      files.push(value);
    } else {
      next(value);
    }
  });
  return files;
};
const replaceAssetsWithUris = (input, replacements) => {
  const clone = cloneDeep(input);
  let index = 0;
  walk(clone, (next, value, key, parent) => {
    if (value instanceof MetaplexFile && index < replacements.length) {
      parent[key] = replacements[index++];
    }

    next(value);
  });
  return clone;
};

export { getAssetsFromJsonMetadata, planUploadMetadataOperation, planUploadMetadataOperationHandler, replaceAssetsWithUris };
//# sourceMappingURL=planUploadMetadata.js.map
