import { defineProperty as _defineProperty } from '../_virtual/_rollupPluginBabelHelpers.js';
import { UnexpectedAccountError } from '../errors/SdkError.js';

class BaseAccount {
  constructor(accountValue) {
    _defineProperty(this, "exists", true);

    this.publicKey = accountValue.publicKey;
    this.executable = accountValue.executable;
    this.owner = accountValue.owner;
    this.lamports = accountValue.lamports;
    this.data = accountValue.data;
    this.rentEpoch = accountValue.rentEpoch;
  }

  static parse(unparsedAccount, accountData) {
    try {
      const data = accountData.fromAccountInfo(unparsedAccount)[0];
      return { ...unparsedAccount,
        data
      };
    } catch (error) {
      throw new UnexpectedAccountError(unparsedAccount.publicKey, accountData.name, error);
    }
  }

  static parseMaybe(unparsedMaybeAccount, accountData) {
    if (!unparsedMaybeAccount.exists) {
      return unparsedMaybeAccount;
    }

    const parsedAccount = this.parse(unparsedMaybeAccount, accountData);
    return { ...parsedAccount,
      exists: true
    };
  }

}

export { BaseAccount };
//# sourceMappingURL=BaseAccount.js.map
