import { resolveClusterFromConnection } from './types/Cluster.js';
import { BundlrStorageDriver } from './plugins/bundlrStorage/BundlrStorageDriver.js';
import { CoreRpcDriver } from './plugins/coreRpcDriver/CoreRpcDriver.js';
import { CoreProgramDriver } from './plugins/coreProgramDriver/CoreProgramDriver.js';
import { CoreOperationDriver } from './plugins/coreOperationDriver/CoreOperationDriver.js';
import { corePlugins } from './plugins/corePlugins/plugin.js';
import { GuestIdentityDriver } from './plugins/guestIdentity/GuestIdentityDriver.js';

class Metaplex {
  /** The connection object from Solana's SDK. */

  /** The cluster in which the connection endpoint belongs to. */

  /** Encapsulates the identity of the users interacting with the SDK. */

  /** Encapsulates where assets should be uploaded. */

  /** Encapsulates how to read and write on-chain. */

  /** Registers all recognised programs across clusters. */

  /** Registers handlers for read/write operations. */
  constructor(connection, options = {}) {
    var _options$cluster;

    this.connection = connection;
    this.cluster = (_options$cluster = options.cluster) !== null && _options$cluster !== void 0 ? _options$cluster : resolveClusterFromConnection(connection);
    this.identityDriver = new GuestIdentityDriver(this);
    this.storageDriver = new BundlrStorageDriver(this);
    this.rpcDriver = new CoreRpcDriver(this);
    this.programDriver = new CoreProgramDriver(this);
    this.operationDriver = new CoreOperationDriver(this);
    this.use(corePlugins());
  }

  static make(connection, options = {}) {
    return new this(connection, options);
  }

  use(plugin) {
    plugin.install(this);
    return this;
  }

  identity() {
    return this.identityDriver;
  }

  setIdentityDriver(identity) {
    this.identityDriver = identity;
    return this;
  }

  storage() {
    return this.storageDriver;
  }

  setStorageDriver(storage) {
    this.storageDriver = storage;
    return this;
  }

  rpc() {
    return this.rpcDriver;
  }

  setRpcDriver(rpc) {
    this.rpcDriver = rpc;
    return this;
  }

  programs() {
    return this.programDriver;
  }

  setProgramDriver(programDriver) {
    this.programDriver = programDriver;
    return this;
  }

  operations() {
    return this.operationDriver;
  }

  setOperationDriver(operationDriver) {
    this.operationDriver = operationDriver;
    return this;
  }

}

export { Metaplex };
//# sourceMappingURL=Metaplex.js.map
