import { MetaplexError } from './MetaplexError.js';

class CandyMachineError extends MetaplexError {
  constructor(input) {
    super({ ...input,
      key: `plugin.candy_machine.${input.key}`,
      title: `Candy Machine > ${input.title}`,
      source: 'plugin',
      sourceDetails: 'Candy Machine'
    });
  }

}
class CandyMachineNotFoundError extends CandyMachineError {
  constructor(candyMachineAddress, cause) {
    super({
      cause,
      key: 'candy_machine_not_found',
      title: 'CandyMachine Not Found',
      problem: 'No Metadata account could be found for the provided candy machine address: ' + `[${candyMachineAddress.toBase58()}].`,
      solution: 'Ensure the provided candy machine address is valid and that an associated ' + 'Metadata account exists on the blockchain.'
    });
  }

}
class CreatedCandyMachineNotFoundError extends CandyMachineError {
  constructor(candyMachineAddress, cause) {
    super({
      cause,
      key: 'created_candy_machine_not_found',
      title: 'Created CandyMachine Not Found',
      problem: 'No Metadata account could be found for the candy machine that the client just created: ' + `[${candyMachineAddress.toBase58()}].`,
      solution: 'Ensure that the candy machine could be created properly and without errors.' + 'If the problem persists please file an issue.'
    });
  }

}

export { CandyMachineError, CandyMachineNotFoundError, CreatedCandyMachineNotFoundError };
//# sourceMappingURL=CandyMachineError.js.map
