import { defineProperty as _defineProperty } from '../../_virtual/_rollupPluginBabelHelpers.js';
import BN from 'bn.js';
import { AssetNotFoundError } from '../../errors/SdkError.js';
import { StorageDriver } from '../../types/StorageDriver.js';
import { SolAmount } from '../../utils/SolAmount.js';

const DEFAULT_BASE_URL = 'https://mockstorage.example.com/';
const DEFAULT_COST_PER_BYTE = new BN(1);
class MockStorageDriver extends StorageDriver {
  constructor(metaplex, options) {
    var _options$baseUrl;

    super(metaplex);

    _defineProperty(this, "cache", {});

    this.baseUrl = (_options$baseUrl = options === null || options === void 0 ? void 0 : options.baseUrl) !== null && _options$baseUrl !== void 0 ? _options$baseUrl : DEFAULT_BASE_URL;
    this.costPerByte = (options === null || options === void 0 ? void 0 : options.costPerByte) != null ? new BN(options === null || options === void 0 ? void 0 : options.costPerByte) : DEFAULT_COST_PER_BYTE;
  }

  async getPrice(...files) {
    const bytes = files.reduce((total, file) => total + file.toBuffer().byteLength, 0);
    return SolAmount.fromLamports(bytes).multipliedBy(this.costPerByte);
  }

  async upload(file) {
    const uri = `${this.baseUrl}${file.uniqueName}`;
    this.cache[uri] = file;
    return uri;
  }

  async download(uri) {
    const file = this.cache[uri];

    if (!file) {
      throw new AssetNotFoundError(uri);
    }

    return file;
  }

  async downloadJson(uri) {
    const file = await this.download(uri);
    return JSON.parse(file.toString());
  }

}

export { MockStorageDriver };
//# sourceMappingURL=MockStorageDriver.js.map
