import { Nft } from './Nft.js';
import { MetadataAccount } from '../../programs/tokenMetadata/accounts/MetadataAccount.js';
import { NftNotFoundError } from '../../errors/NftError.js';
import { useOperation } from '../../types/Operation.js';
import { OriginalOrPrintEditionAccount } from '../../programs/tokenMetadata/accounts/OriginalOrPrintEditionAccount.js';

const Key = 'FindNftByMintOperation';
const findNftByMintOperation = useOperation(Key);
const findNftByMintOnChainOperationHandler = {
  handle: async (operation, metaplex) => {
    const mint = operation.input;
    const [metadata, edition] = await metaplex.rpc().getMultipleAccounts([await MetadataAccount.pda(mint), await OriginalOrPrintEditionAccount.pda(mint)]);
    const metadataAccount = MetadataAccount.fromMaybe(metadata);
    const editionAccount = OriginalOrPrintEditionAccount.fromMaybe(edition);

    if (!metadataAccount.exists) {
      throw new NftNotFoundError(mint);
    }

    const nft = new Nft(metadataAccount, metaplex);

    try {
      await nft.metadataTask.run();
    } catch (e) {// Fail silently...
    }

    nft.editionTask.loadWith(editionAccount.exists ? editionAccount : null);
    return nft;
  }
};

export { findNftByMintOnChainOperationHandler, findNftByMintOperation };
//# sourceMappingURL=findNftByMint.js.map
