import { Nft } from './Nft.js';
import { GmaBuilder } from '../../utils/GmaBuilder.js';
import { zipMap } from '../../utils/common.js';
import { useOperation } from '../../types/Operation.js';
import { MetadataAccount } from '../../programs/tokenMetadata/accounts/MetadataAccount.js';

const Key = 'FindNftsByMintListOperation';
const findNftsByMintListOperation = useOperation(Key);
const findNftsByMintListOnChainOperationHandler = {
  handle: async (operation, metaplex) => {
    const mints = operation.input;
    const metadataPdas = await Promise.all(mints.map(mint => MetadataAccount.pda(mint)));
    const metadataInfos = await GmaBuilder.make(metaplex, metadataPdas).get();
    return zipMap(metadataPdas, metadataInfos, (metadataPda, metadataInfo) => {
      if (!metadataInfo || !metadataInfo.exists) return null;

      try {
        const metadata = MetadataAccount.from(metadataInfo);
        return new Nft(metadata, metaplex);
      } catch (error) {
        return null;
      }
    });
  }
};

export { findNftsByMintListOnChainOperationHandler, findNftsByMintListOperation };
//# sourceMappingURL=findNftsByMintList.js.map
