import { UninitializedWalletAdapterError, OperationNotSupportedByWalletAdapterError } from '../../errors/SdkError.js';
import { IdentityDriver } from '../../types/IdentityDriver.js';

class WalletAdapterIdentityDriver extends IdentityDriver {
  constructor(metaplex, walletAdapter) {
    super(metaplex);
    this.walletAdapter = walletAdapter;
  }

  get publicKey() {
    if (!this.walletAdapter.publicKey) {
      throw new UninitializedWalletAdapterError();
    }

    return this.walletAdapter.publicKey;
  }

  async signMessage(message) {
    if (this.walletAdapter.signMessage === undefined) {
      throw new OperationNotSupportedByWalletAdapterError('signMessage');
    }

    return this.walletAdapter.signMessage(message);
  }

  async signTransaction(transaction) {
    if (this.walletAdapter.signTransaction === undefined) {
      throw new OperationNotSupportedByWalletAdapterError('signTransaction');
    }

    return this.walletAdapter.signTransaction(transaction);
  }

  async signAllTransactions(transactions) {
    if (this.walletAdapter.signAllTransactions === undefined) {
      throw new OperationNotSupportedByWalletAdapterError('signAllTransactions');
    }

    return this.walletAdapter.signAllTransactions(transactions);
  }

  async sendTransaction(transaction, _connection, options) {
    const {
      signers,
      ...sendOptions
    } = options || {}; // We accept a connection to match the wallet signature, but it is not used.
    // We use the RpcDriver to send the transaction to keep the single point of failure.

    return this.metaplex.rpc().sendTransaction(transaction, signers, sendOptions);
  }

}

export { WalletAdapterIdentityDriver };
//# sourceMappingURL=WalletAdapterIdentityDriver.js.map
