import { Connection } from '@solana/web3.js';
import { MetaplexPlugin, Cluster, IdentityDriver, StorageDriver, RpcDriver, ProgramDriver, OperationDriver } from "./types";
export declare type MetaplexOptions = {
    cluster?: Cluster;
};
export declare class Metaplex {
    /** The connection object from Solana's SDK. */
    readonly connection: Connection;
    /** The cluster in which the connection endpoint belongs to. */
    readonly cluster: Cluster;
    /** Encapsulates the identity of the users interacting with the SDK. */
    protected identityDriver: IdentityDriver;
    /** Encapsulates where assets should be uploaded. */
    protected storageDriver: StorageDriver;
    /** Encapsulates how to read and write on-chain. */
    protected rpcDriver: RpcDriver;
    /** Registers all recognised programs across clusters. */
    protected programDriver: ProgramDriver;
    /** Registers handlers for read/write operations. */
    protected operationDriver: OperationDriver;
    constructor(connection: Connection, options?: MetaplexOptions);
    static make(connection: Connection, options?: MetaplexOptions): Metaplex;
    use(plugin: MetaplexPlugin): this;
    identity(): IdentityDriver;
    setIdentityDriver(identity: IdentityDriver): this;
    storage(): StorageDriver;
    setStorageDriver(storage: StorageDriver): this;
    rpc(): RpcDriver;
    setRpcDriver(rpc: RpcDriver): this;
    programs(): ProgramDriver;
    setProgramDriver(programDriver: ProgramDriver): this;
    operations(): OperationDriver;
    setOperationDriver(operationDriver: OperationDriver): this;
}
