import NodeBundlr, { WebBundlr } from '@bundlr-network/client';
import BigNumber from 'bignumber.js';
import { Metaplex } from "../../Metaplex";
import { StorageDriver, MetaplexFile } from "../../types";
import { SolAmount } from "../../utils";
export interface BundlrOptions {
    address?: string;
    timeout?: number;
    providerUrl?: string;
    priceMultiplier?: number;
    withdrawAfterUploading?: boolean;
}
export declare class BundlrStorageDriver extends StorageDriver {
    protected bundlr: WebBundlr | NodeBundlr | null;
    protected options: BundlrOptions;
    protected _withdrawAfterUploading: boolean;
    constructor(metaplex: Metaplex, options?: BundlrOptions);
    getBalance(): Promise<SolAmount>;
    getPrice(...files: MetaplexFile[]): Promise<SolAmount>;
    upload(file: MetaplexFile): Promise<string>;
    uploadAll(files: MetaplexFile[]): Promise<string[]>;
    fundingNeeded(filesOrBytes: MetaplexFile[] | number, skipBalanceCheck?: boolean): Promise<BigNumber>;
    needsFunding(filesOrBytes: MetaplexFile[] | number, skipBalanceCheck?: boolean): Promise<boolean>;
    fund(filesOrBytes: MetaplexFile[] | number, skipBalanceCheck?: boolean): Promise<void>;
    protected getBytes(filesOrBytes: MetaplexFile[] | number): number;
    protected getMultipliedPrice(bytes: number): Promise<BigNumber>;
    protected uploadFile(file: MetaplexFile): Promise<string>;
    withdrawAll(): Promise<void>;
    withdraw(lamports: BigNumber | number): Promise<void>;
    shouldWithdrawAfterUploading(): boolean;
    withdrawAfterUploading(): this;
    dontWithdrawAfterUploading(): this;
    getBundlr(): Promise<WebBundlr | NodeBundlr>;
}
