/// <reference types="node" />
import { Buffer } from 'buffer';
import { AccountInfo, Blockhash, Commitment, ConfirmOptions, GetProgramAccountsConfig, PublicKey, SendOptions, Transaction, TransactionSignature } from '@solana/web3.js';
import { RpcDriver, ConfirmTransactionResponse, SendAndConfirmTransactionResponse, Signer, UnparsedAccount, UnparsedMaybeAccount } from "../../types";
import { TransactionBuilder } from "../../utils";
import { MetaplexError } from "../../errors";
export declare class CoreRpcDriver extends RpcDriver {
    sendTransaction(transaction: Transaction | TransactionBuilder, signers?: Signer[], sendOptions?: SendOptions): Promise<TransactionSignature>;
    confirmTransaction(signature: TransactionSignature, commitment?: Commitment): Promise<ConfirmTransactionResponse>;
    sendAndConfirmTransaction(transaction: Transaction | TransactionBuilder, signers?: Signer[], confirmOptions?: ConfirmOptions): Promise<SendAndConfirmTransactionResponse>;
    getAccount(publicKey: PublicKey, commitment?: Commitment): Promise<UnparsedMaybeAccount>;
    getMultipleAccounts(publicKeys: PublicKey[], commitment?: Commitment): Promise<UnparsedMaybeAccount[]>;
    getProgramAccounts(programId: PublicKey, configOrCommitment?: GetProgramAccountsConfig | Commitment): Promise<UnparsedAccount[]>;
    protected getLatestBlockhash(): Promise<Blockhash>;
    protected getDefaultFeePayer(): PublicKey | undefined;
    protected getUnparsedMaybeAccount(publicKey: PublicKey, accountInfo: AccountInfo<Buffer> | null): UnparsedMaybeAccount;
    protected parseProgramError(error: unknown, transaction: Transaction): MetaplexError;
}
