import { PublicKey } from '@solana/web3.js';
import { ModuleClient } from "../../types";
import { Plan } from "../../utils";
import { Nft } from './Nft';
import { UploadMetadataInput, UploadMetadataOutput } from './uploadMetadata';
import { CreateNftInput, CreateNftOutput } from './createNft';
import { UpdateNftInput, UpdateNftOutput } from './updateNft';
import { PrintNewEditionOutput, PrintNewEditionSharedInput, PrintNewEditionViaInput } from './printNewEdition';
export declare class NftClient extends ModuleClient {
    findNftByMint(mint: PublicKey): Promise<Nft>;
    findNftsByMintList(mints: PublicKey[]): Promise<(Nft | null)[]>;
    findNftsByOwner(owner: PublicKey): Promise<Nft[]>;
    findNftsByCreator(creator: PublicKey, position?: number): Promise<Nft[]>;
    findNftsByCandyMachine(candyMachine: PublicKey, version?: 1 | 2): Promise<Nft[]>;
    uploadMetadata(input: UploadMetadataInput): Promise<UploadMetadataOutput>;
    planUploadMetadata(input: UploadMetadataInput): Promise<Plan<undefined, UploadMetadataOutput>>;
    createNft(input: CreateNftInput): Promise<{
        nft: Nft;
    } & CreateNftOutput>;
    updateNft(nft: Nft, input: Omit<UpdateNftInput, 'nft'>): Promise<{
        nft: Nft;
    } & UpdateNftOutput>;
    printNewEdition(originalMint: PublicKey, input?: Omit<PrintNewEditionSharedInput, 'originalMint'> & PrintNewEditionViaInput): Promise<{
        nft: Nft;
    } & PrintNewEditionOutput>;
}
