import { Commitment, ConfirmOptions, GetProgramAccountsConfig, PublicKey, RpcResponseAndContext, SendOptions, SignatureResult, Transaction, TransactionSignature } from '@solana/web3.js';
import { Signer, UnparsedAccount, UnparsedMaybeAccount } from "./";
import { TransactionBuilder } from "../utils";
import { Driver } from './Driver';
export declare type ConfirmTransactionResponse = RpcResponseAndContext<SignatureResult>;
export declare type SendAndConfirmTransactionResponse = {
    signature: TransactionSignature;
    confirmResponse: ConfirmTransactionResponse;
};
export declare abstract class RpcDriver extends Driver {
    abstract sendTransaction(transaction: Transaction | TransactionBuilder, signers?: Signer[], sendOptions?: SendOptions): Promise<TransactionSignature>;
    abstract confirmTransaction(signature: TransactionSignature, commitment?: Commitment): Promise<ConfirmTransactionResponse>;
    abstract sendAndConfirmTransaction(transaction: Transaction | TransactionBuilder, signers?: Signer[], confirmOptions?: ConfirmOptions): Promise<SendAndConfirmTransactionResponse>;
    abstract getAccount(publicKey: PublicKey, commitment?: Commitment): Promise<UnparsedMaybeAccount>;
    abstract getMultipleAccounts(publicKeys: PublicKey[], commitment?: Commitment): Promise<UnparsedMaybeAccount[]>;
    abstract getProgramAccounts(programId: PublicKey, configOrCommitment?: GetProgramAccountsConfig | Commitment): Promise<UnparsedAccount[]>;
}
